@@ -1,8 +1,8 @@
-#===================================================
-# OOo2DBK : OpenOffice-Writer to Docbook
-#===================================================
-# Copyright (c) 2004 Nuxeo SARL <http://nuxeo.com>
-# Copyright (c) 2002 Eric Bellot <ebellot@netcourrier.com>
+#==================================================================
+# OOo2DBK : OpenOffice.org Writer document to DocBook XML converter
+#==================================================================
+# (C) Copyright 2004-2005 Nuxeo SARL <http://nuxeo.com>
+# (C) Copyright Eric Bellot <ebellot@netcourrier.com>
 #
 # Authors:
 # Ruslan Spivak (Nuxeo)
@@ -25,5 +25,6 @@
 #
 # See ``COPYING`` for more information
 #
-# $Id: __init__.py 20384 2004-11-26 13:32:07Z madarche $
-from ooo2dbk import convert, convert2, exec_args
+# $Id: __init__.py 29929 2005-11-25 10:45:04Z madarche $
+from ooo2dbk import convert, execArgs
+
